@@ -537,7 +537,7 @@ gb_eval_compare (GBEvalContext *ec,
 
 		/* FIXME: may need expanding to chomp whitespace away ? */
 
-		l_num = g_strcasecmp (l->v.s->str, r->v.s->str);
+		l_num = strcmp (l->v.s->str, r->v.s->str);
 		r_num = 0;
 
 		switch (t) {
