@@ -24,7 +24,7 @@ get_project_pair (GBEvalContext *ec, GBValue *v, GBLexerStream *ls)
 	char          *s;
 
 	if (v->gtk_type != gb_gtk_type_from_value (GB_VALUE_STRING)) {
-		gb_eval_exception_fire (ec, "Expecting a string';'");
+		gb_eval_exception_fire (ec, _("Expecting a string';'"));
 		return NULL;
 	}
 
@@ -60,7 +60,7 @@ split_known (GBEvalContext *ec, char *key, GBValue *value,
 
 	} else if (!g_strcasecmp (key, "Startup")) {
 		if (!value->gtk_type == gb_gtk_type_from_value (GB_VALUE_STRING)) {
-			gb_eval_exception_fire (ec, "Expecting a textual startup");
+			gb_eval_exception_fire (ec, _("Expecting a textual startup"));
 			return FALSE;
 		}
 
@@ -83,7 +83,7 @@ split_known (GBEvalContext *ec, char *key, GBValue *value,
 	} else if (!g_strcasecmp (key, "Form")) {
 
 		if (!value->gtk_type == gb_gtk_type_from_value (GB_VALUE_STRING)) {
-			gb_eval_exception_fire (ec, "Expecting a value after ';'");
+			gb_eval_exception_fire (ec, _("Expecting a value after ';'"));
 			return FALSE;
 		}
 		proj->forms = g_slist_prepend (proj->forms,
@@ -116,7 +116,7 @@ parse_project (GBEvalContext *ec, GBLexerStream *ls, GBProject *proj)
 		if (token == '[') { /* Discard a section heading */
 			token = gb_lex_real (&res, ls);
 			if (token != NAME) {
-				gb_eval_exception_fire (ec, "Malformed section heading");
+				gb_eval_exception_fire (ec, _("Malformed section heading"));
 				return FALSE;
 			}
 
@@ -124,21 +124,21 @@ parse_project (GBEvalContext *ec, GBLexerStream *ls, GBProject *proj)
 
 			token = gb_lex_real (&res, ls);
 			if (token != ']') {
-				gb_eval_exception_fire (ec, "Missing section delimiter");
+				gb_eval_exception_fire (ec, _("Missing section delimiter"));
 				return FALSE;
 			}
 			continue;
 		}
 
 		if (token != NAME) {
-			gb_eval_exception_fire (ec, "Expecting name");
+			gb_eval_exception_fire (ec, _("Expecting name"));
 			return FALSE;
 		}
 		key = (char *)res.v_str;
 
 		token = gb_lex_real (&res, ls);
 		if (token != '=') {
-			gb_eval_exception_fire (ec, "Expecting '='");
+			gb_eval_exception_fire (ec, _("Expecting '='"));
 			return FALSE;
 		}
 
@@ -154,7 +154,7 @@ parse_project (GBEvalContext *ec, GBLexerStream *ls, GBProject *proj)
 			break;
 
 		default:
-			gb_eval_exception_fire (ec, "Expecting a value");
+			gb_eval_exception_fire (ec, _("Expecting a value"));
 			g_free (key);
 			return FALSE;
 		}
