@@ -61,11 +61,15 @@ typedef struct _GBProjectPair       GBProjectPair;
 typedef struct _GBFormItem          GBFormItem;
 typedef struct _GBFormProperty      GBFormProperty;
 
+/* gb-class.h */
+typedef struct _GBClassProperty     GBClassProperty;
+
 /* gb-main.h */
 typedef struct _GBParseData GBParseData;
 typedef struct _GBRoutine   GBRoutine;
 typedef struct _GBVar       GBVar;
 typedef struct _GBIndex     GBIndex;
+typedef struct _GBOptions   GBOptions;
 
 /* gb-statement.h */
 typedef struct _GBStatement  GBStatement;
@@ -74,6 +78,7 @@ typedef struct _GBSelectCase GBSelectCase;
 /* gb-type.h */
 typedef struct _GBType       GBType;
 typedef struct _GBTypeElem   GBTypeElem;
+typedef struct _GBConst      GBConst;
 
 /* gb-lex.h */
 typedef struct _GBLexerStream      GBLexerStream;
