@@ -39,13 +39,13 @@
 
 struct _GBRunFileHandle {
         /* VB related */
-        int       used;
-	int       fileno;
-	OpenMode  mode;
-	guint     recordlen;
+        int         used;
+	int         fileno;
+	GBSOpenMode mode;
+	guint       recordlen;
 
 	/* Internal */
-	FILE     *file;
+	FILE       *file;
 };
 
 static GBRunFileHandle *
