@@ -648,14 +648,7 @@ gbrun_object_has_method (GBRunObjectClass *klass,
 		return FALSE;
 }
 
-typedef struct {
-	GtkType type;
-	int     idx;
-	char   *name;
-	int     flags;
-} GBRunObjectProperty;
-
-static GBRunObjectProperty *
+GBRunObjectProperty *
 gbrun_object_get_property (GBRunObjectClass  *klass,
 			   const char        *name,
 			   GBRunObjectClass **on_class,
@@ -663,6 +656,7 @@ gbrun_object_get_property (GBRunObjectClass  *klass,
 {
 	GSList *l, *i;
 
+	g_return_val_if_fail (name != NULL, NULL);
 	g_return_val_if_fail (klass != NULL, NULL);
 
 	for (i = klass->priv->classes; i; i = i->next) {
@@ -785,9 +779,10 @@ gbrun_method_invoke_arg (GBRunEvalContext *ec, GBRunObject    *obj,
 		if (expr) {
 			GBValue *v = gb_eval_context_eval (GB_EVAL_CONTEXT (ec), expr);
 			
-			if (!v)
+			if (!v) {
 				exception = TRUE;
-			else {
+				break;
+			} else {
 				vals [i] = gbrun_value_promote_name (ec, v, arg->type_name);
 				gb_value_destroy (v);
 			}
@@ -1376,6 +1371,8 @@ gbrun_object_subclass (GtkType           parent,
 
 		type = gtk_type_unique (parent, &object_info);
 		gtk_type_class (type);
+
+		g_free (query);
 	}
 
 	g_free (gtk_name);
