@@ -72,14 +72,29 @@ gbrun_project_copy (GBEvalContext  *ec,
 
 static gboolean
 gbrun_project_assign (GBEvalContext  *ec,
-		      GBObject       *object,
+		      GBObject       *obj,
 		      const GBObjRef *ref,
 		      GBValue        *value,
 		      gboolean        try_assign)
 {
+	GSList *l;
+	gboolean ret;
+	GBRunProject *proj = GBRUN_PROJECT (obj);
+
 	if (!try_assign)
 		g_error ("Can't assign to project");
 
+	for (l = proj->priv->modules; l; l = l->next) {
+		if ((ret = gb_object_assign (ec, GB_OBJECT (l->data),
+					     ref, value, TRUE))
+		    || gb_eval_exception (ec)) {
+#ifdef PROJECT_DEBUG
+			g_warning ("Found method '%s' on a module", ref->name);
+#endif
+			return ret;
+		}
+	}
+
 	return FALSE;
 }
 
@@ -360,7 +375,7 @@ gbrun_project_new (GBRunEvalContext *ec, GBProject *p,
 		gb_object_unref (GB_OBJECT (obj));
 
 		gbrun_form_init (ec, GBRUN_FORM (obj), pd);
-		gbrun_form_invoke (ec, GBRUN_FORM (obj), "Form_Load");
+		gbrun_form_invoke (ec, GBRUN_FORM (obj), "Form_Load", NULL);
 #endif
 		/* FIXME: this should be attached to the object somehow */
 		gb_options_copy (&ec->options, &pd->options);
