@@ -349,6 +349,35 @@ gbrun_stmt_redim (GBRunEvalContext  *ec,
 	return TRUE;
 }
 
+gboolean
+gbrun_stmt_erase (GBRunEvalContext  *ec,
+		  const GBStatement *stmt)
+{
+	GBValue *tmp;
+	GBObjRef r;
+
+	g_return_val_if_fail (stmt->parm.erase.var_name != NULL, FALSE);
+
+	r.method = FALSE;
+	r.name   = stmt->parm.erase.var_name;
+	r.parms  = NULL;
+
+	tmp = gbrun_objref_deref (ec, NULL, &r, TRUE);
+	if (!tmp)
+		return FALSE;
+
+	if (!gtk_type_is_a (tmp->gtk_type, GBRUN_TYPE_ARRAY)) {
+		gbrun_exception_firev (ec, _("Can only erase arrays"));
+		return FALSE;
+	}
+
+	gbrun_array_erase (ec, GBRUN_ARRAY (tmp->v.obj));
+
+	gb_value_destroy (tmp);
+	
+	return TRUE;
+}
+
 static gboolean
 gbrun_stmt_case (GBRunEvalContext *ec,
 		 GBValue          *val,
@@ -557,14 +586,19 @@ gbrun_stmt_while (GBRunEvalContext  *ec,
 	GBValue      *val;
 	GBBoolean     going = TRUE;
 
-	val = gb_eval_context_eval (GB_EVAL_CONTEXT (ec),
-				    stmt->parm.do_while.expr);
+	if (!stmt->parm.do_while.expr)
+		going = TRUE;
 
-	if (!gb_eval_compare (GB_EVAL_CONTEXT (ec),
-			      val, GB_EXPR_EQ, GBTrue_value, &going))
-		return FALSE;
+	else {
+		val = gb_eval_context_eval (GB_EVAL_CONTEXT (ec),
+					    stmt->parm.do_while.expr);
+
+		if (!gb_eval_compare (GB_EVAL_CONTEXT (ec),
+				      val, GB_EXPR_EQ, GBTrue_value, &going))
+			return FALSE;
 			
-	gb_value_destroy (val);
+		gb_value_destroy (val);
+	}
 			
 	if (going)
 		gbrun_frame_stmts_push (ec, stmt->parm.do_while.body);
@@ -713,6 +747,41 @@ gbrun_stmt_foreach (GBRunEvalContext  *ec,
 	return retval;
 }
 
+static gboolean
+gbrun_stmt_with (GBRunEvalContext  *ec,
+		 const GBStatement *stmt,
+		 gboolean init)
+{
+	GBValue *value;
+
+	value = gb_eval_context_eval (GB_EVAL_CONTEXT (ec),
+				      stmt->parm.with.base_obj);
+
+	if (!value)
+		return FALSE;
+
+	else if (!gtk_type_is_a (value->gtk_type, GB_TYPE_OBJECT)) {
+		gbrun_exception_firev (ec, _("With needs an object"));
+		return FALSE;
+	}
+
+	if (init) {
+		gbrun_frame_stmts_push (ec, stmt->parm.with.body);
+
+		gbrun_eval_context_with_push (ec, value->v.obj);
+		gb_value_destroy (value);
+	} else {
+		GBObject *obj = gbrun_eval_context_with_pop (ec);
+
+		if (obj)
+			gb_object_unref (obj);
+		else
+			g_warning ("Weird - with stack corrupted");
+	}
+
+	return TRUE;
+}
+
 /*
  * stack_seek_root:
  * 
@@ -739,6 +808,9 @@ stack_find (GBRunEvalContext  *ec,
 	    GBRunSubFrame    **dest_sf,
 	    GSList           **dest_stmt)
 {
+	if (!sf)
+		return;
+
 	if (sf->stmts) {
 		GBStatement *stmt = sf->stmts->data;
 		if (stmt->type == t) {
@@ -767,6 +839,8 @@ gbrun_stmt_exit (GBRunEvalContext  *ec,
 		break;
 	case GBS_EXIT_DO:
 		stack_find (ec, rf->cur, GBS_DO, &dest_sf, &dest_stmt);
+		if (!dest_sf)
+			stack_find (ec, rf->cur, GBS_WHILE, &dest_sf, &dest_stmt);
 		break;
 	case GBS_EXIT_FOR:
 		stack_find (ec, rf->cur, GBS_FOR, &dest_sf, &dest_stmt);
@@ -953,6 +1027,10 @@ gbrun_stmt_evaluate (GBRunEvalContext *ec, const GBStatement *stmt, gboolean ini
 		return gbrun_stmt_foreach (ec, stmt, init);
 
 	case GBS_WITH:
+		return gbrun_stmt_with (ec, stmt, init);
+
+	case GBS_ERASE:
+		return gbrun_stmt_erase (ec, stmt);
 
 	default:
 		gbrun_exception_firev (ec, _("Unhandled statement '%s'"),
