@@ -9,10 +9,37 @@
 #ifndef GBRUN_FORM_ITEM_H
 #define GBRUN_FORM_ITEM_H
 
+/*
+ * Alignment values
+ */
 #define VB_LEFT_JUSTIFY		0
 #define VB_RIGHT_JUSTIFY	1
 #define VB_CENTER_JUSTIFY	2
 
+/*
+ * Fill Style values
+ */
+#define VB_FILL_SOLID		0		/* Solid */
+#define VB_FILL_TRANS		1		/* Transparent */
+#define VB_FILL_HLINE		2		/* Horizontal Line */
+#define VB_FILL_VLINE		3		/* Vertical Line */
+#define VB_FILL_UP_DIAG		4		/* Upward Diagonal */
+#define VB_FILL_DOWN_DIAG	5		/* Downward Diagonal */
+#define VB_FILL_CROSS		6		/* Cross */
+#define VB_FILL_DIAG_CROSS	7		/* Diagonal Cross */
+
+/*
+ * Shape values
+ */
+#define VB_SHAPE_RECTANGLE	0		/* Rectangle */
+#define VB_SHAPE_SQUARE		1		/* Square */
+#define VB_SHAPE_OVAL		2		/* Oval */
+#define VB_SHAPE_CIRCLE		3		/* Circle */
+#define VB_SHAPE_RRECT		4		/* Rounded Rectangle */
+#define VB_SHAPE_RSQUARE	5		/* Rounded Square */
+
+/*
+ */
 #define VB_TRUE		       -1
 #define VB_FALSE		0
 
@@ -29,13 +56,17 @@
 struct _GBRunFormItem {
 	GBRunObject     object;
 
-	GBRunForm      *form;
+	GBRunObject    *parent;
 	int             x, y;
 	GtkWidget      *widget;
 	char           *name;
 	int             tabindex;
 	char           *tag;
 	int		index;
+
+	int		scaleheight;
+	int		scalewidth;
+	int		scalemode;
 	
 	GSList	       *carray;
 };
@@ -50,6 +81,24 @@ typedef struct {
 		     GBRunFormItem *item,
 		     GBRunForm *to_form,
 		     const char *name);
+
+	void (*addsub) (GBRunEvalContext *ec,
+		        GBRunFormItem    *subitem,
+		        GBRunFormItem    *item,
+		        GBRunForm        *to_form,
+		        const char       *name);
+
+	GtkFixed *(*get_fixed) (GBRunEvalContext *ec,
+		                 GBRunFormItem    *item);
+
+	gboolean (*get_radio_btn) (GBRunEvalContext *ec,
+		                   GBRunFormItem    *item,
+		                   GtkWidget        **radio_btn);
+
+	void (*set_radio_btn) (GBRunEvalContext *ec,
+		               GBRunFormItem    *item,
+		               GtkWidget        *radio_btn);
+
 } GBRunFormItemClass;
 
 #define GBRUN_FORM_ITEM_KEY "GBRunFormItemWidgetKey"
@@ -61,6 +110,12 @@ void           gbrun_form_item_add         (GBRunEvalContext *ec,
 					    GBRunForm        *to_form,
 					    const char       *name);
 
+void           gbrun_form_subitem_add      (GBRunEvalContext *ec,
+					    GBRunFormItem    *subitem,
+					    GBRunFormItem    *item,
+					    GBRunForm        *to_form,
+					    const char       *name);
+
 GBRunFormItem *gbrun_form_item_new         (GBRunEvalContext *ec,
 					    GtkType           type);
 
