@@ -189,6 +189,7 @@ enum {
 	LEFT,
 	SCALE_HEIGHT,
 	SCALE_WIDTH,
+	SCALE_MODE,
 	TOP,
 	WIDTH,
 	LINK_TOPIC,
@@ -201,6 +202,26 @@ enum {
 	CONTROLBOX
 };
 
+static const char* p_name[] = {
+	"Arg_First",
+	"Caption",
+	"Height",
+	"Left",
+	"Scale_Height",
+	"Scale_Width",
+	"Scale_Mode",
+	"Top",
+	"Width",
+	"Link_Topic",
+	"Startup_Position",
+	"Border_Style",
+	"Max_Button",
+	"Min_Button",
+	"Show_in_taskbar",
+	"Tag",
+	"Controlbox"
+};
+
 /**
  * form_setarg
  *   @ec
@@ -254,9 +275,21 @@ form_setarg (GBRunEvalContext *ec,
 	case TAG:
 		form->tag = g_strdup (val->v.s->str);
 		return TRUE;
+	
+	case SCALE_HEIGHT:
+		form->scaleheight = val->v.i;
+		return TRUE;
+	
+	case SCALE_WIDTH:
+		form->scalewidth = val->v.i;
+		return TRUE;
+
+	case SCALE_MODE:
+		form->scalemode = val->v.i;
+		return TRUE;
 
 	default:
-		g_warning ("form: Unhandled property '%d'", property);
+		g_warning ("form: Set of unhandled property '%s'", p_name[property]);
 		return FALSE;
 	}
 }
@@ -293,11 +326,20 @@ form_getarg (GBRunEvalContext *ec,
 		return gb_value_new_int (GBRUN_FORM_Y_TO_TWIPS (i));
 	}
 
+	case SCALE_HEIGHT:
+		return gb_value_new_int (form->scaleheight);
+	
+	case SCALE_WIDTH:
+		return gb_value_new_int (form->scalewidth);
+
+	case SCALE_MODE:
+		return gb_value_new_int (form->scalemode);
+
 	case TAG: 
 		return gb_value_new_string_chars (form->tag);
 
 	default:
-		g_warning ("form: Unhandled property '%d'", property);
+		g_warning ("form: get of unhandled property '%s'", p_name[property]);
 		break;
 	}
 
@@ -398,7 +440,7 @@ void
 gbrun_form_show (GBRunForm *form)
 {
 	g_return_if_fail (GBRUN_IS_FORM (form));
-	
+
 	gtk_widget_show_all (GTK_WIDGET (form->window));
 }
 
@@ -411,8 +453,8 @@ gbrun_form_add (GBRunForm         *form,
 	g_return_if_fail (name != NULL);
 	g_return_if_fail (form != NULL);
 
-	item->form = form;
-	item->name = g_strdup (name);
+	item->parent = GBRUN_OBJECT (form);
+	item->name   = g_strdup (name);
 
 	gtk_fixed_put (form->fixed, item->widget, 0, 0);
 }
@@ -471,9 +513,10 @@ gbrun_form_invoke (GBRunEvalContext *ec,
 	} GBFormItemSib;
 		
 /**
- * gbrun_form_new:
+ * gbrun_form_init:
  *   @ec: 
- *   @item: 
+ *   @form: 
+ *   @pd:
  * 
  **/
 void
@@ -503,7 +546,7 @@ gbrun_form_init (GBRunEvalContext  *ec,
 	for (l = item->children; l; l = l->next) {
 		GBFormItem       *i = l->data;
 		GtkType           type;
-		GBRunFormItem    *item;
+		GBRunFormItem    *item2;
 
 		type = gb_gtk_type_from_name (i->type);
 		if (!type) {
@@ -511,7 +554,7 @@ gbrun_form_init (GBRunEvalContext  *ec,
 			continue;
 		}
 
-		item = gbrun_form_item_new (ec, type);
+		item2 = gbrun_form_item_new (ec, type);
 		
 		/*
 		 * Check for arrays by looking for duplicates (siblings).
@@ -524,7 +567,7 @@ gbrun_form_init (GBRunEvalContext  *ec,
 			if ( !g_strcasecmp(fi_sib->name, i->name) &&
 			     !g_strcasecmp(fi_sib->type, i->type)     ) {
 				fi_sib->item->carray = 
-					g_slist_append (fi_sib->item->carray, item);
+					g_slist_append (fi_sib->item->carray, item2);
 				dup_item = TRUE;
 				break;
 			}
@@ -534,27 +577,52 @@ gbrun_form_init (GBRunEvalContext  *ec,
 		 * We first let the item add itself to the form
 		 * and after that pass properties. FIXME: Does this make sense?
 		 */
-		gbrun_form_item_add (ec, item, form, i->name);
+		gbrun_form_item_add (ec, item2, form, i->name);
 
-		gbrun_form_pass_properties (ec, GBRUN_OBJECT (item), i);
+		gbrun_form_pass_properties (ec, GBRUN_OBJECT (item2), i);
 
 		if (!dup_item) {
 			/* Add it to the stack */
-			gbrun_object_ref (item);
+			gbrun_object_ref (item2);
 			gbrun_stack_add  (ec, i->name,
-					  gb_value_new_object (GB_OBJECT (item)),
+					  gb_value_new_object (GB_OBJECT (item2)),
 					  GBRUN_STACK_MODULE);
 			
 			new_sib = g_new (GBFormItemSib, 1);
 			new_sib->name = g_strdup (i->name);
 			new_sib->type = g_strdup (i->type);
-			new_sib->item = item;
+			new_sib->item = item2;
 			my_siblings = g_slist_append (my_siblings, new_sib);
 		}
 
-		if (i->children)
-			g_warning ("Discarding children on item '%s' of type '%s'",
-				   i->name, i->type);
+		if (i->children) {
+			GSList		*c;
+
+			if (i->children->data)
+				g_warning ("Processing children on item '%s' of type '%s'",
+					   i->name, i->type);
+
+			for (c = i->children; c; c = c->next) {
+				GBFormItem	*ii = c->data;
+				GtkType		 type_sub;
+				GBRunFormItem	*subitem;
+
+				if (ii) {
+					type_sub = gb_gtk_type_from_name (ii->type);
+					if (!type_sub) {
+						g_warning ("Unknown sub-form type '%s'", ii->type);
+						continue;
+					}
+					
+					subitem = gbrun_form_item_new (ec, type_sub);
+
+					gbrun_form_subitem_add (ec, subitem, item2, form, ii->name);
+
+					gbrun_form_pass_properties (ec, GBRUN_OBJECT (subitem), ii);
+
+				}
+			}
+		}
 	}
 
 	for (sib = my_siblings; sib; sib = sib->next) {
@@ -731,6 +799,8 @@ gbrun_form_instance_init (GBRunForm *form)
 
 	gtk_window_add_accel_group (GTK_WINDOW (form->window),
 				    form->accel_group);
+
+	form->radio_btn = NULL;
 }
 
 static void
@@ -748,6 +818,7 @@ gbrun_form_class_init (GBRunObjectClass *klass)
 	gbrun_object_add_property (klass, "clientleft", gb_type_int, LEFT);
 	gbrun_object_add_property (klass, "scaleheight",  gb_type_int, SCALE_HEIGHT);
 	gbrun_object_add_property (klass, "scalewidth",   gb_type_int, SCALE_WIDTH);
+	gbrun_object_add_property (klass, "scalemode",    gb_type_int, SCALE_MODE);
 	gbrun_object_add_property (klass, "top",    gb_type_int, TOP);
 	gbrun_object_add_property (klass, "clienttop", gb_type_int, TOP);
 	gbrun_object_add_property (klass, "width",  gb_type_int, WIDTH);
