@@ -39,15 +39,19 @@
 #define GBRUN_IS_FORM(obj) (GTK_CHECK_TYPE ((obj), gbrun_form_get_type ()))
 
 struct _GBRunForm {
-	GBRunObject object;
+	GBRunObject     object;
 
-	GtkWindow  *window;
-	GtkMenuBar *menubar;
-	GtkFixed   *fixed;
-	GtkAccelGroup *accel_group;
+	GtkWindow      *window;
+	GtkMenuBar     *menubar;
+	GtkFixed       *fixed;
+	GtkAccelGroup  *accel_group;
+	GtkWidget      *radio_btn;
 
 	/* Form properties */
-	char       *tag;
+	char           *tag;
+	int             scalemode;
+	int             scaleheight;
+	int             scalewidth;
 };
 
 typedef struct {
