@@ -20,6 +20,16 @@ enum {
 	MULTILINE
 };
 
+
+static const char* p_name[] = {
+	"Arg_First",
+	"Locked",
+	"Tooltip_Text",
+	"Text",
+	"Alignment",
+	"Multiline"
+};
+
 #define GBRUN_TEXTBOX(obj) (GTK_CHECK_CAST ((obj), gbrun_textbox_get_type (), GBRunTextBox))
 
 typedef struct {
@@ -84,7 +94,7 @@ textbox_setarg (GBRunEvalContext *ec,
 	}
 
 	default:
-		g_warning ("textbox: Unhandled property '%d'", property);
+		g_warning ("textbox: Set of unhandled property '%s'", p_name[property]);
 		return FALSE;
 	}
 }
@@ -116,7 +126,7 @@ textbox_getarg (GBRunEvalContext *ec,
 			gtk_entry_get_text (entry));
 
 	default:
-		g_warning ("textbox: Unhandled property '%d'", property);
+		g_warning ("textbox: get of unhandled property '%s'", p_name[property]);
 		return NULL;
 	}
 }
